# ICDPICPY

International Classification of Diseases Programs for Injury Categorization in Python

The ICDPICPY package is an implementation of the R program ICDPICR (https://github.com/ablack3/icdpicr) in Python. 
